# Patient-specific mapping of fundus photographs to three-dimensional ocular imaging

This example contains raytracing simulations and analyses for the paper [*Patient-specific mapping of fundus photographs to three-dimensional ocular imaging*](https://doi.org/10.1002/mp.17576).
This example consists of two parts: the first part demonstrates the raytracing simulations, and the second part performs some analyses on these results.
This example is kept up to date with changes in ZOSPy. The version used for the publication can be accessed here: [zospy.readthedocs.io/fundusscaling](https://zospy.readthedocs.io/fundusscaling).

```{toctree}
:maxdepth: 1

1_raytracing
2_analysis
```
